====================================
Introduction: fmralign in a nutshell
====================================


Functional alignment: handling functional variability
=====================================================

Functional alignment seek to handle functional variability by learning a transformation
from one subject to another. It can be useful to better transfer knowledge of
functional characteristics across subjects or to improve `decoding <https://nilearn.github.io/decoding/index.html>`_.


Installing fmralign
===================

In a Python 3 environnment :

```
pip install fmralign
```
